@@ -1,13 +1,12 @@
-__version__ = "0.3.1"
-
 from cvargparse.argument import Argument
+from cvargparse.argument import Argument as Arg
 from cvargparse.argument import FileArgument
-Arg = Argument
-
+from cvargparse.argument import JupyterArguments
 from cvargparse.factory import ArgFactory
 from cvargparse.factory import BaseFactory
-from cvargparse.parser import BaseParser
-from cvargparse.parser import GPUParser
+from cvargparse.parser.base import BaseParser
+from cvargparse.parser.gpu_parser import GPUParser
+from cvargparse.parser.mode_parser import ModeParserFactory
 
 __all__ = [
 	"Arg",
@@ -16,5 +15,6 @@ __all__ = [
 	"ArgFactory",
 	"BaseFactory",
 	"BaseParser",
+	"ModeParserFactory",
 	"GPUParser",
 ]
